<?php
namespace Bushelpowered\Api\Platform\Commodity\V1\Model;
        
class TenantCommodityStandard implements \Bushelpowered\Api\Common\Event\StandardRecord, \Bushelpowered\Api\Common\HasSourceTimestamps, \Bushelpowered\Api\Common\HasTimestamps
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var null|string $sourceLocationId The source location identifier.*/
    public ?string $sourceLocationId = null;
    /** @var null|string $locationId The location identifier.*/
    public ?string $locationId = null;
    /** @var null|string $sourceDisplayName The display name coming from the datasource.*/
    public ?string $sourceDisplayName = null;
    /** @var null|string $displayName The display name.*/
    public ?string $displayName = null;
    /** @var null|string $commodityId The standard commodity identifier. This identifier value is that of the commodity variety.*/
    public ?string $commodityId = null;
    /** @var null|string $className The standard commodity class name (e.g. Grain, Oilseed).*/
    public ?string $className = null;
    /** @var null|string $groupName The standard commodity group name (e.g. Corn, Wheat).*/
    public ?string $groupName = null;
    /** @var null|string $subgroupName The standard commodity subgroup name (e.g. Yellow, White).*/
    public ?string $subgroupName = null;
    /** @var null|string $varietyName The standard commodity variety name (e.g. #1, #2, Organic).*/
    public ?string $varietyName = null;
    /** @var null|string $accountId The bushel id of the account that owns this record, if any.*/
    public ?string $accountId = null;
    /** @var string $updatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var string $createdAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var null|string $deletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $deletedAt = null;
    /** @var string $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var string $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var null|string $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  null|string  $sourceLocationId The source location identifier.
     * @param  null|string  $locationId The location identifier.
     * @param  null|string  $sourceDisplayName The display name coming from the datasource.
     * @param  null|string  $displayName The display name.
     * @param  null|string  $commodityId The standard commodity identifier. This identifier value is that of the commodity variety.
     * @param  null|string  $className The standard commodity class name (e.g. Grain, Oilseed).
     * @param  null|string  $groupName The standard commodity group name (e.g. Corn, Wheat).
     * @param  null|string  $subgroupName The standard commodity subgroup name (e.g. Yellow, White).
     * @param  null|string  $varietyName The standard commodity variety name (e.g. #1, #2, Organic).
     * @param  null|string  $accountId The bushel id of the account that owns this record, if any.
     * @param  string  $updatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $deletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $tenantId, string $datasourceId, string $integrationId, string $sourceId, ?string $sourceLocationId, ?string $locationId, ?string $sourceDisplayName, ?string $displayName, ?string $commodityId, ?string $className, ?string $groupName, ?string $subgroupName, ?string $varietyName, ?string $accountId, string $updatedAt, string $createdAt, ?string $deletedAt, string $sourceCreatedAt, string $sourceUpdatedAt, ?string $sourceDeletedAt)
    {
        $this->id = $id;
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceLocationId = $sourceLocationId;
        $this->locationId = $locationId;
        $this->sourceDisplayName = $sourceDisplayName;
        $this->displayName = $displayName;
        $this->commodityId = $commodityId;
        $this->className = $className;
        $this->groupName = $groupName;
        $this->subgroupName = $subgroupName;
        $this->varietyName = $varietyName;
        $this->accountId = $accountId;
        $this->updatedAt = $updatedAt;
        $this->createdAt = $createdAt;
        $this->deletedAt = $deletedAt;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
    }
    
    /**
     * @return string The primary unique identifier.
     */
    public function getId(): string
    {
        return $this->id;
    }
    /**
     * @return string The tenant identifier.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The datasource identifier.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The source record identifier.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return null|string The location identifier.
     */
    public function getLocationId(): ?string
    {
        return $this->locationId;
    }
    /**
     * @return null|string The bushel id of the account that owns this record, if any.
     */
    public function getAccountId(): ?string
    {
        return $this->accountId;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return null|string The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getDeletedAt(): ?string
    {
        return $this->deletedAt;
    }
    /**
     * @return string Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return string Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return null|string Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
}