<?php
namespace Bushelpowered\Api\Trade\Futures\V1\Response;
        
class LocationResponse implements \Bushelpowered\Api\Common\HasCreatedAtTimestamp, \Bushelpowered\Api\Common\HasUpdatedAtTimestamp, \Bushelpowered\Api\Common\HasDeletedAtTimestamp
{
    /** @var string $id The unique identifier for a specific Location.*/
    public string $id;
    /** @var string $companyId The unique identifier for a specific Company related to the Location.*/
    public string $companyId;
    /** @var int $centreId The unique identifier for centre.*/
    public int $centreId;
    /** @var int $cqgCategoryId The identifier for the CQG symbol.*/
    public int $cqgCategoryId;
    /** @var string $displayName The name that is displayed for the Location.*/
    public string $displayName;
    /** @var int $sortOrder The order in which the Location should be displayed in the API response.*/
    public int $sortOrder;
    /** @var null|string $salesSeriesId The sales series from CQG-accounts project.*/
    public ?string $salesSeriesId = null;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var null|string $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $deletedAt = null;

    /**
     * @param  string  $id The unique identifier for a specific Location.
     * @param  string  $companyId The unique identifier for a specific Company related to the Location.
     * @param  int  $centreId The unique identifier for centre.
     * @param  int  $cqgCategoryId The identifier for the CQG symbol.
     * @param  string  $displayName The name that is displayed for the Location.
     * @param  int  $sortOrder The order in which the Location should be displayed in the API response.
     * @param  null|string  $salesSeriesId The sales series from CQG-accounts project.
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $companyId, int $centreId, int $cqgCategoryId, string $displayName, int $sortOrder, ?string $salesSeriesId, string $createdAt, string $updatedAt, ?string $deletedAt)
    {
        $this->id = $id;
        $this->companyId = $companyId;
        $this->centreId = $centreId;
        $this->cqgCategoryId = $cqgCategoryId;
        $this->displayName = $displayName;
        $this->sortOrder = $sortOrder;
        $this->salesSeriesId = $salesSeriesId;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
        $this->deletedAt = $deletedAt;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return null|string Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getDeletedAt(): ?string
    {
        return $this->deletedAt;
    }
}